/*
 * Definio do Menu de Aplicaes para o WindowMaker
 *
 * Sintaxe:
 *
 * <Title> [SHORTCUT <tecla de atalho>] <Comando> <Parmetros>
 *
 * <Title>  qualquer texto a ser usado como ttulo. Deve estar entre aspas "
 * 
 * SHORTCUT especifica uma tecla de atalho para o item. <tecla de atalho> 
 * tem a mesma sintaxe das teclas de atalho em $HOME/GNUstep/Defaults/WindowMaker
 *
 * No  possvel especificar teclas de atalho para MENU ou OPEN_MENU
 * 
 * <Command>  um dos seguintes comandos:
 *	MENU - inicia definio de um (sub)menu
 *	END  - termina definio de um (sub)menu
 *	OPEN_MENU - abre um menu apartir de um arquivo, comando pipeado ou
 *		contedo de um diretrio com um comando opcional para cada
 *		arquivo no diretrio.
 *	WORKSPACE_MENU - adiciona menu para operaes sobre reas de Trabalho
 *	EXEC <programa> - executa um programa
 *	EXIT - termina o gerenciador de janelas
 *	SHEXEC <command> - executa comando de shell (ex.: gimp > /dev/null)
 *	RESTART [<gerenciador de janelas>] - reinicia o WindowMaker ou inicia 
 *		 	outro gerenciador de janelas
 *	REFRESH - fora repintagem da rea de trabalho
 *	ARRANGE_ICONS - arruma os cones na rea de trabalho
 *	SHUTDOWN - mata todos os programas (terminando a sesso do X)
 *	SHOW_ALL - abre todas as janelas na rea de trabalho
 *	HIDE_OTHERS - esconde (hide) todas as janelas na rea de trabalho,
 *		exceto a que estiver ativa
 *	SAVE_SESSION - salva o estado da rea de trabalho, o que inclui
 *		todos os programas em execuo, informaes relativas
 *		a posio, tamanho, rea de trabalho onde se localizam,
 *		o dock ou clip de onde foi lanado e se a janela est 
 *		miniaturizada, shadeada ou hideada. Tambm salva qual a rea
 *		de trabalho atual. Todas as informaes sero restauradas
 *		at que se use o comando SAVE_SESSION de novo ou CLEAR_SESSION.
 *		Se SaveSessionOnExit = Yes; estiver definido no domnio 
 *		WindowMaker ($HOME/GNUstep/Defaults/WindowMaker), ento o 
 *		salvamento da sesso  feito automaticamente quando o 
 *		WindowMaker finalizar, apagando quaisquer SAVE_SESSION ou
 *		CLEAR_SESSION usados anteriormente.
 *	CLEAR_SESSION - apaga uma sesso salvada anteriormente. Este comando
 *		no ter efeito algum se SaveSessionOnExit estiver habilitado.
 *	INFO_PANEL - mostra a janela de informaes do programa
 *      LEGAL_PANEL - mostra janela de informacoes legais
 *
 * Sintaxe do OPEN_MENU:
 *   1. Uso com outros arquivos de menu:
 *	// abre o arquivo arquivo.menu que deve conter um menu vlido
 *	// e o insere naquela posio.
 *	OPEN_MENU arquivo.menu
 *   2. Uso com comandos pipeados:
 *	// executa o comando e usa a sua sada para construir o menu.
 *	// A sada do menu deve ser uma descrio de menu vlida.
 *	// O espao entre o '|' e o comando  opcional.
 *	OPEN_MENU | comando
 *   3. Uso com diretrios:
 *	// Abre um ou mais diretrios e constri um menu com todos
 *	// os subdiretrios e arquivos executveis neles, em ordem
 *	// alfabtica.
 *	OPEN_MENU /algum/diretrio [/algum/outro/diretrio ...]
 *   4. Uso com diretrios e comando:
 *	// Abre um ou mais diretrios e constri um menu com todos os
 *	// subdiretrios e arquivos legveis neles em ordem alfabtica,
 *	// usando o comando para executar cada arquivo.
 *
 *	OPEN_MENU [-noext] /algum/dir [/algum/outro/dir ...] WITH comando -opes
 *		
 *
 * <Parmetros>  o programa a ser executado.
 *
 * ** Cdigos especiais para o programa a ser executado:
 * %s - substitui pela seleo atual
 * %a(mensagem) - abre uma janela de entrada com a mensagem e substitui
 *	pelo que for digitado nela
 * %w - substitui pelo XID da janela selecionada
 *
 * Para ignorar caracteres especiais, tais como % e ", use \ na frente deles.
 * ex: xterm -T "\"Hello World\""
 *
 * Tambm  possvel usar caracteres de escape, como \n
 *
 * Cada comando MENU deve ter um END correspondente no fim.
 *
 * Exemplo:
 *
 * "Teste" MENU
 *	"XTerm" EXEC xterm
 *		// cria um submenu com o contedo de /usr/openwin/bin
 *	"XView apps" OPEN_MENU "/usr/openwin/bin"
 *		// alguns programas do X11 em vrios diretrios
 *	"X11 apps" OPEN_MENU /usr/X11/bin $HOME/bin/X11
 *		// faz um submenu de papis de parede
 *	"Papel de Parede" OPEN_MENU $HOME/imagens /usr/share/imagens WITH wmsetbg -u -t
 *		// insere o menu meu.menu 
 *	"Style" OPEN_MENU meu.menu
 * "Test" END
 */

#include "wmmacros"

"Aplicaes" MENU
	"Informaes" MENU
		"Informaes..." INFO_PANEL
		"Informaes Legais" LEGAL_PANEL
		"Console do Sistema" EXEC xconsole
		"Carga do Sistema" SHEXEC xosview || xload
		"Lista de Processos" EXEC xterm -e top
		"Leitor de Manual" EXEC xman
	"Informaes" END
	"XTerm" EXEC xterm -sb 
	"Rxvt" EXEC rxvt -bg black -fg white -fn fixed
	"reas de Trabalho" WORKSPACE_MENU
	"Aplicaes" MENU
		"Grficos" MENU
			"Gimp" SHEXEC gimp >/dev/null
			"XV" EXEC xv
			"XPaint" EXEC xpaint
			"XFig" EXEC xfig
		"Grficos" END
		"X File Manager" EXEC xfm
		"OffiX Files" EXEC files
		"LyX" EXEC lyx
		"Netscape" EXEC netscape 
  		"Ghostview" EXEC ghostview %a(Enter file to view)
		"Acrobat" EXEC /usr/pkg/Acrobat3/bin/acroread %a(Enter PDF to view)
  		"TkDesk" EXEC tkdesk
	"Aplicaes" END
	"Editores" MENU
		"XFte" EXEC xfte
		"XEmacs" SHEXEC xemacs || emacs
		"XJed" EXEC xjed 
		"NEdit" EXEC nedit
		"Xedit" EXEC xedit
		"VI" EXEC xterm -e vi
	"Editores" END
	"Diversos" MENU
		"Xmcd" SHEXEC xmcd 2> /dev/null
		"Xplaycd" EXEC xplaycd
		"Xmixer" EXEC xmixer
	"Diversos" END
	"Utilitrios" MENU
		"Calculadora" EXEC xcalc
		"Propriedades da Janela" SHEXEC xprop | xmessage -center -title 'xprop' -file -
		"Seletor de Fontes" EXEC xfontsel
		"Emulador de Terminal" EXEC xminicom
		"Lente de Aumento" EXEC xmag
		"Colormap" EXEC xcmap
		"XKill" EXEC xkill
		"ASClock" EXEC asclock -shape
		"Clipboard" EXEC xclipboard
	"Utilitrios" END

	"Seleo" MENU
		"Copiar" SHEXEC echo '%s' | wxcopy
		"eMail Para" EXEC xterm -name mail -T "Pine" -e pine %s
		"Navegar" EXEC netscape %s
		"Procurar Manual" SHEXEC MANUAL_SEARCH(%s)
	"Seleo" END

	"rea de Trabalho" MENU
		"Hide Outros" HIDE_OTHERS
		"Mostrar Todos" SHOW_ALL
		"Arrumar cones" ARRANGE_ICONS
		"Refresh" REFRESH
		"Lock" EXEC xlock -allowroot -usefirst
		"Salvar Sesso" SAVE_SESSION
		"Apagar Sesso Salvada" CLEAR_SESSION
	"rea de Trabalho" END

	"Aparncia" MENU
		"Temas" OPEN_MENU -noext THEMES_DIR $HOME/GNUstep/Library/WindowMaker/Themes WITH setstyle
		"Estilos" OPEN_MENU -noext STYLES_DIR $HOME/GNUstep/Library/WindowMaker/Styles WITH setstyle
		"Conjunto de cones" OPEN_MENU -noext ICON_SETS_DIR $HOME/GNUstep/Library/WindowMaker/IconSets WITH seticons
		"Papis de Parede" MENU
			"Slido" MENU
                        	"Preto" WS_BACK '(solid, black)'
                        	"Azul"  WS_BACK '(solid, "#505075")'
				"Indigo" WS_BACK '(solid, "#243e6c")'
				"Azul escuro" WS_BACK '(solid, "#224477")'
                        	"Roxo" WS_BACK '(solid, "#554466")'
                        	"Creme"  WS_BACK '(solid, "wheat4")'
                        	"Cinza Escuro"  WS_BACK '(solid, "#333340")'
                        	"Vinho" WS_BACK '(solid, "#400020")'
			"Slido" END
			"Degrad" MENU
				"Bandeira" WS_BACK '(mdgradient, green, green, yellow)'
				"Cu" WS_BACK '(vgradient, blue4, white)'
			"Degrad" END
			"Imagens" OPEN_MENU -noext BACKGROUNDS_DIR $HOME/GNUstep/Library/WindowMaker/Backgrounds WITH wmsetbg -u -t
		"Papis de Parede" END
		"Salvar Tema" SHEXEC getstyle -t $HOME/GNUstep/Library/WindowMaker/Themes/"%a(Nome do Tema)"
		"Salvar Configurao de cones" SHEXEC geticonset $HOME/GNUstep/Library/WindowMaker/IconSets/"%a(Nome do Conjunto de cones)"
	"Appearance" END

	"Sair"	MENU
		"Reiniciar" RESTART
		"Iniciar AfterStep" RESTART afterstep
		"Sair..."  EXIT
		"Terminar Sesso..." SHUTDOWN
	"Sair" END
"Aplicaes" END


